//========================================================================
//
// SplashFontFileID.cc
//
//========================================================================

#include <config.h>

#include "SplashFontFileID.h"

//------------------------------------------------------------------------
// SplashFontFileID
//------------------------------------------------------------------------

SplashFontFileID::SplashFontFileID() = default;

SplashFontFileID::~SplashFontFileID() = default;
